@@ -153,7 +153,7 @@ def build(app_path):
 
     requirements_txt_path = os.path.join(app_path, 'requirements.txt')
     venv_path = os.path.join(app_path, 'venv')
-    venv_bin_dir = virtualenv.path_locations(venv_path)[3]
+    _, venv_lib_dir, _, venv_bin_dir = virtualenv.path_locations(venv_path)
     venv_python_path = os.path.join(venv_bin_dir, 'python')
     venv_previous_requirements_path = os.path.join(venv_path, 'requirements.txt')
 
@@ -189,6 +189,14 @@ def build(app_path):
                 *
                 '''))
 
+    # if PYTHONPATH is defined (this is how Tide bundles packages on Mac and Linux),
+    # the packages there have precidence over the packages in this virtualenv. That
+    # prevents the user upgrading anything that's bundled, so we'll add the virtualenv's
+    # packages in front of the existing PYTHONPATH.
+    if 'PYTHONPATH' in os.environ:
+        venv_site_packages = os.path.join(venv_lib_dir, 'site-packages')
+        os.environ['PYTHONPATH'] = venv_site_packages + ':' + os.environ['PYTHONPATH']
+
     requirements_unchanged_since_last_run = (
         os.path.isfile(venv_previous_requirements_path)
         and filecmp.cmp(requirements_txt_path, venv_previous_requirements_path)
@@ -289,17 +297,23 @@ def main():
         app_path = os.path.abspath(args['<app>'])
 
         if args['simulate']:
-            return simulate(app_path)
+            simulate(app_path)
+
         elif args['run']:
-            return run(app_path, args['<hostname>'])
+            run(app_path, args['<hostname>'])
+
         elif args['install']:
-            return install(app_path, args['<hostname>'])
+            install(app_path, args['<hostname>'])
+
         elif args['build']:
-            return build(app_path)
+            build(app_path)
+
         elif args['clean']:
-            return clean(app_path)
+            clean(app_path)
+
         elif args['tingbot_run']:
-            return tingbot_run(app_path)
+            tingbot_run(app_path)
+
     except Exception as e:
         for arg in e.args:
             if isinstance(arg, int) and arg == e.args[0]:
