@@ -1,5 +1,5 @@
 import os
-
+from ..utils import only_call_once
 
 def fixup_env():
     import evdev
@@ -33,26 +33,18 @@ def register_button_callback(callback):
     ensure_button_setup()
     button_callback = callback
 
-button_setup_done = False
+button_pins = (17, 23, 24, 14)
 
+@only_call_once
+def ensure_wiringpi_setup():
+    import wiringpi
+    wiringpi.wiringPiSetupGpio()
+
+@only_call_once
 def ensure_button_setup():
-    global button_setup_done
-    if not button_setup_done:
-        button_setup()
-    button_setup_done = True
-
-button_pins = (17, 23, 24, 18)
-button_pin_to_index = {
-    17: 0,
-    23: 1,
-    24: 2,
-    18: 3
-}
-
-def button_setup():
     import wiringpi
 
-    wiringpi.wiringPiSetupGpio()
+    ensure_wiringpi_setup()
 
     for button_pin in button_pins:
         wiringpi.pinMode(button_pin, wiringpi.INPUT)
@@ -67,7 +59,30 @@ def GPIO_callback():
     button_states = [wiringpi.digitalRead(pin) for pin in button_pins]
 
     for button_index, (old, new) in enumerate(zip(button_previous_states, button_states)):
-        if old != new:
+        if old != new and button_callback is not None:
             button_callback(button_index, 'down' if (new == 1) else 'up')
 
     button_previous_states = button_states
+
+@only_call_once
+def ensure_backlight_setup():
+    import subprocess
+    subprocess.check_call(['gpio', '-g', 'mode', '18', 'pwm'])
+    subprocess.check_call(['gpio', '-g', 'pwmr', '65536'])
+
+def set_backlight(brightness):
+    '''
+    Sets the backlight of the screen to `brightness`. `brightness` is a number from 0 to 100.
+    '''
+    import subprocess
+
+    ensure_backlight_setup()
+
+    if brightness <= 4:
+        # linear scaling from 0 to 4
+        value = brightness
+    else:
+        # cubic scaling from 4 to 100
+        value = 65536 * (brightness/100.0)**3
+
+    subprocess.check_call(['gpio', '-g', 'pwm', '18', str(value)])
